@@ -1,8 +1,7 @@
 from airpage.core import *
-from airpage.fileIO.wechat import *
 
-
-
+IDENTITY = True
+XXX = lambda:...
 
 
 
